<?php
/**
* GNU General Public License.

* This file is part of ZeusCart V3.0.

* ZeusCart V3.0 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
* 
* ZeusCart V3.0 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with Foobar. If not, see <http://www.gnu.org/licenses/>.
*
*/

/**
 * CAdminHome
 *
 * This class contains functions to get the data needed for the site statistics from various tables
 *
 * @package		Core_CAdminHome
 * @category	Core
 * @author		ZeusCart Team
 * @link		http://www.zeuscart.com
 * @version 	2.3
 */


class Core_CAdminHome
{	
	/**
	 * Function gets the categories available from the categroy_table. 
	 * 
	 * 
	 * @return string
	 */
	function getCategory()
    {
		$sql = "SELECT count(category_name) as totalCat FROM category_table where category_parent_id=0";
		$obj = new Bin_Query();
		if($obj->executeQuery($sql))
	       return  $obj->records[0]['totalCat'];
    }
	
	/**
	 * Function gets the current month orders from orders_table.
	 * 
	 * 
	 * @return string
	 */
	
	function monthlyOrders()
	{
	    $sql="select count(*)as cnt from orders_table a where month(a.date_purchased)=MONTH(CURRENT_DATE)";
		$obj = new Bin_Query();
		if($obj->executeQuery($sql))
			return  $obj->records[0]['cnt'];
	}
	
	/**
	 * Function gets the previous month orders from orders_table.
	 * 
	 * 
	 * @return string
	 */	
	
	
	function previousMonthOrders()
	{
	    $sql="select count(*)as cnt from orders_table a where month(a.date_purchased)=MONTH(CURRENT_DATE)-1";
		$obj = new Bin_Query();
		if($obj->executeQuery($sql))
		   return  $obj->records[0]['cnt'];
	
	}
	
	/**
	 * Function gets the count of pending orders from orders_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function pendingOrders()
	{
	    $sql="select count(*)as cnt from orders_table where orders_status=1";
		$obj = new Bin_Query();
		if($obj->executeQuery($sql))
		       return  $obj->records[0]['cnt'];
	}
	
	/**
	 * Function gets the count of orders under processing from orders_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function processingOrders()
	{
	   $sql="select count(*)as cnt from orders_table where orders_status=2";
		$obj = new Bin_Query();
		if($obj->executeQuery($sql))
	       return  $obj->records[0]['cnt'];
	}
	
	/**
	 * Function gets the count of orders that are delivered  from orders_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function deliveredOrders()
	{
	   $sql="select count(*)as cnt from orders_table where orders_status=3";
		$obj = new Bin_Query();
		if($obj->executeQuery($sql))
	       return  $obj->records[0]['cnt'];
	}
	
	/**
	 * Function gets the count of total orders from orders_table.
	 * 
	 * 
	 * @return string
	 */			
	
	function totalOrders()
	{
	     $sql="select count(*) as cnt from orders_table";
		 $obj = new Bin_Query();
		if($obj->executeQuery($sql))
			return  $obj->records[0]['cnt'];
	}
	
	/**
	 * Function gets the count of current month user strength from users_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function currentMonthUser()
	{
	     $sql="select count(*)as cnt from users_table a where month(a.user_doj)=MONTH(a.user_doj)";
		 $obj = new Bin_Query();
 		 if($obj->executeQuery($sql))
			return  $obj->records[0]['cnt'];
	}
	
	/**
	 * Function gets the products under low stock from the product_invetory_table.
	 * 
	 * 
	 * @return string
	 */	
	 
	function lowStock()
	{
	    $sql="select count(*) as cnt from product_inventory_table where rol>=soh";
		$obj = new Bin_Query();
		if($obj->executeQuery($sql))
			return  $obj->records[0]['cnt'];
	}
	
	/**
	 * Function gets the previous month user strength from the users_table.
	 * 
	 * 
	 * @return string
	 */	
	
	
	function previousMonthUser()
	{
	     $sql="select count(*)as cnt from users_table a where month(a.user_doj)=MONTH(a.user_doj)-1";
		 $obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
				$output=$obj->records[0]['cnt'];
				return  $output;
		}
	}
	
	/**
	 * Function gets the total users count from the users_table.
	 * 
	 * 
	 * @return string
	 */	
		
	function totalUsers()
	{
	   $sql="select count(*)as cnt from users_table ";
	   $obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
				$output=$obj->records[0]['cnt'];
				return  $output;
		}
	}
	
	
	/**
	 * Function gets the current month income from multiple tables.
	 * 
	 * 
	 * @return string
	 */	
	
	
	function currentMonthIncome()
	{
//		$sql = "select sum(a.msrp-a.price) as monthlyincome from products_table a inner join order_products_table b on a.product_id=b.product_id inner join orders_table c on c.orders_id=b.order_id where month(c.date_purchased)=MONTH(CURRENT_DATE) ";
	/*	$sql="select sum(b.product_qty*b.product_unit_price) as monthlyincome from products_table a inner join order_products_table b on a.product_id=b.product_id inner join orders_table c on c.orders_id=b.order_id where month(c.date_purchased)=MONTH(CURRENT_DATE)";
			 $obj = new Bin_Query();			 
		if($obj->executeQuery($sql))
		{		
		       
				$output=$obj->records[0]['monthlyincome'];
				return  $output;
		}*/
		$sql1="select a.order_total from orders_table a inner join users_table b on a.customers_id=b.user_id inner join orders_status_table c on a.orders_status=c.orders_status_id where month(a.date_purchased)=MONTH(CURRENT_DATE) order by a.date_purchased desc";
		//$sql1="select a.order_total from orders_table a inner join users_table b on a.customers_id=b.user_id inner join orders_status_table c on c.orders_status_id=a.orders_status inner join country_table d on d.cou_code=a.billing_country inner join country_table e on e.cou_code=a.shipping_country inner join paymentgateways_table f on f.gateway_id=a.payment_method left join shipments_master_table g on g.shipment_id=a.shipment_id_selected where month(a.date_purchased)=MONTH(CURRENT_DATE)";
		   $obj1=new Bin_Query();
		   $obj1->executeQuery($sql1);
		   $res1=$obj1->records;
		   $subtotal=array();
		   foreach($res1 as $row)
		      $subtotal[]=$row['order_total'];
  		return number_format(array_sum($subtotal),2);
	}
	
	
	/**
	 * Function gets the previous month income from multiple tables.
	 * 
	 * 
	 * @return string
	 */	
	
	
	function previoustMonthIncome()
	{
		/*//$sql = "select sum(a.msrp-a.price) as monthlyincome from products_table a inner join order_products_table b on a.product_id=b.product_id inner join orders_table c on c.orders_id=b.order_id where month(c.date_purchased)=MONTH(CURRENT_DATE)-1 ";
		$sql="select sum(b.product_qty*b.product_unit_price) as monthlyincome from products_table a inner join order_products_table b on a.product_id=b.product_id inner join orders_table c on c.orders_id=b.order_id where month(c.date_purchased)=MONTH(CURRENT_DATE)-1";
			 $obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
					$output=$obj->records[0]['monthlyincome'];
				return  $output;
		}*/
		$sql1="select a.order_total from orders_table a inner join users_table b on a.customers_id=b.user_id inner join orders_status_table c on a.orders_status=c.orders_status_id where month(a.date_purchased)=MONTH(CURRENT_DATE)-1 order by a.date_purchased desc";
		//$sql1="select a.order_total from orders_table a inner join users_table b on a.customers_id=b.user_id inner join orders_status_table c on c.orders_status_id=a.orders_status inner join country_table d on d.cou_code=a.billing_country inner join country_table e on e.cou_code=a.shipping_country inner join paymentgateways_table f on f.gateway_id=a.payment_method left join shipments_master_table g on g.shipment_id=a.shipment_id_selected where month(a.date_purchased)=MONTH(CURRENT_DATE)-1";
		   $obj1=new Bin_Query();
		   $obj1->executeQuery($sql1);
		   $res1=$obj1->records;
		   $subtotal=array();
		   foreach($res1 as $row)
		      $subtotal[]=$row['order_total'];
			return   number_format(array_sum($subtotal),2);
	}

	/**
	 * Function gets the total income from multiple tables.
	 * 
	 * 
	 * @return string
	 */		
	
	function totalIncome()
	{
		/*$sql = "select sum(b.product_qty*b.product_unit_price) as totalincome from products_table a inner join order_products_table b on a.product_id=b.product_id inner join orders_table c on c.orders_id=b.order_id ";
			 $obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
				$output=$obj->records[0]['totalincome'];
				return  $output;
		}*/
		// $sql1="select a.order_total from orders_table a inner join users_table b on a.customers_id=b.user_id inner join orders_status_table c on a.orders_status=c.orders_status_id  order by a.date_purchased desc";
		$sql1="select a.order_total from orders_table a inner join users_table b on a.customers_id=b.user_id inner join orders_status_table c on c.orders_status_id=a.orders_status inner join country_table d on d.cou_code=a.billing_country inner join country_table e on e.cou_code=a.shipping_country inner join paymentgateways_table f on f.gateway_id=a.payment_method left join shipments_master_table g on g.shipment_id=a.shipment_id_selected";
		   $obj1=new Bin_Query();
		   $obj1->executeQuery($sql1);
		   $res1=$obj1->records;
		   $subtotal=array();
		   foreach($res1 as $row)
		      $subtotal[]=$row['order_total'];		  
 		return  number_format(array_sum($subtotal),2);
		}
	
	
	/**
	 * Function gets count of products enabled from the products_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function enabledProducts()
	{
	   $sql="select count(*) as cnt from products_table where status=1";
	   			 $obj = new Bin_Query();
		if($obj->executeQuery($sql))
			return  $obj->records[0]['cnt'];
	}
	
	/**
	 * Function gets count of products that are disabled from the products_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function disabledProducts()
	{
	   $sql="select count(*) as cnt from products_table where status=0";
	   			 $obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
				$output= $obj->records[0]['cnt'];
				return  $output;
		}
	}
	
	
	/**
	 * Function gets total products count from the products_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function totalProducts()
	{
	   $sql="select count(*) as cnt from products_table ";
	   			 $obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
				$output=$obj->records[0]['cnt'];
				return  $output;
		}
	}
	
	/**
	 * Function gets current month product quantity from multiple tables.
	 * 
	 * 
	 * @return string
	 */		
	
	function currentMonthProudctQuantity()
	{
	   $sql = "select sum(b.product_qty) as productquantity from products_table a inner join order_products_table b on a.product_id=b.product_id inner join orders_table c on c.orders_id=b.order_id where month(c.date_purchased)=MONTH(CURRENT_DATE) ";
			 $obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
				$output=$obj->records[0]['productquantity'];
				return  $output;
		}
	}
	
	/**
	 * Function gets previous month product quantity from multiple tables.
	 * 
	 * 
	 * @return string
	 */		
	
	function previousMonthProudctQuantity()
	{
	   $sql = "select sum(b.product_qty) as productquantity from products_table a inner join order_products_table b on a.product_id=b.product_id inner join orders_table c on c.orders_id=b.order_id where month(c.date_purchased)=MONTH(CURRENT_DATE)-1 ";
			 $obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
			$output=$obj->records[0]['productquantity'];
			return  $output;
		}
	}
	
	/**
	 * Function gets the total product quantity from multiple tables.
	 * 
	 * 
	 * @return string
	 */		
	
	function totalProudctQuantity()
	{
	   $sql = "select sum(b.product_qty) as productquantity from products_table a inner join order_products_table b on a.product_id=b.product_id inner join orders_table c on c.orders_id=b.order_id ";
			 $obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
			$output=$obj->records[0]['productquantity'];
			return  $output;
		}
	}
	
	
	/**
	 * Function gets count of products available from products_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function getProducts()
    {
        
		$sql = "SELECT count(product_id) as totalproducts FROM products_table ";
		$obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{	
			//echo $obj->records[0]['totalproducts'];	
			if($obj->records[0]['totalproducts']==0)
			{
				return 0;
			}
			else
			{
				return $obj->records[0]['totalproducts'];
			}
		}
	 
    }
		
	/**
	 * Function gets count of customer details from the users_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function getCustomers()
	{
		
		$sql = "SELECT count(user_id) as totalcustomers FROM users_table";
		$obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
			return  $obj->records[0]['totalcustomers'];
		}	
	}
	
	/**
	 * Function gets order count from the orders_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function getOrderCount()
	{
		$sql = "SELECT count(orders_id) as totalorders FROM orders_table where orders_status=1";
		$obj = new Bin_Query();

		if($obj->executeQuery($sql))
		{		
				//print_r($obj->totrows);
				if(((int)$obj->totrows)>0)
				{
					return $obj->records[0]['totalorders'];

				}
				else
				{
					return 0;
				}	
		}
		 
	}
	
	/**
	 * Function sets the admin and subadmin name in the session for displaying.
	 * 
	 * 
	 * @return string
	 */		
	
	function userName()
	{
		include_once('classes/Core/CAdminActivity.php');
		$user='';
		$id=0;
		$flag=1;
		if($_SESSION['adminId']!='')
		{
			 $user=$_SESSION['adminName'];
			 $id=$_SESSION['adminId'];
		}	 
		else if($_SESSION['subadminId']!='')
		{
 			 $user=$_SESSION['subadminName'];
			 $id=$_SESSION['subadminId'];
			 $flag=0;
		}	 
		
		Core_CAdminActivity::setReport($user,$id,$flag);

		return $user;
	}
	
	
	/**
	 * Function gets the latest customer details from users_table.
	 * 
	 * 
	 * @return string
	 */		
	
	function getLatestCustomers($dashname)
	{
	
	
	  
		//include('classes/Display/DAdminHome.php');
		$sql = "SELECT * FROM users_table order by user_doj desc limit 0,8";
		$obj = new Bin_Query();
		$obj->executeQuery($sql);
				
			return  Display_DAdminHome::getLatestCustomers($obj->records,$dashname);		
		
	}
	
	/**
	 * Function gets the products in order table.
	 * 
	 * 
	 * @return string
	 */	
	
	function productsInOrderTable()
	{
	    $sql="select a.title,c.date_purchased,b.product_unit_price,b.product_qty,b.shipping_cost,((b.product_qty*b.product_unit_price)+b.shipping_cost)as subtotal  from products_table a inner join order_products_table b on a.product_id=b.product_id inner join orders_table c  order by c.date_purchased desc limit 0,10 ";
		$obj = new Bin_Query();
		if($obj->executeQuery($sql))
		{		
		   $sql1="select ((b.product_qty*b.product_unit_price)+b.shipping_cost)as subtotal  from products_table a inner join order_products_table b on a.product_id=b.product_id inner join orders_table c  order by c.date_purchased desc limit 0,10 ";
            $obj1=new Bin_Query();
			$obj1->executeQuery($sql1);
			$arr=$obj1->records;
			$arrval= array();

			$sumofval=0;
			foreach($arr as $r)
			{
			   $arrval[]=$r['subtotal'];
			}
			 
			return  Display_DAdminHome::productsInOrderTable($obj->records,array_sum($arrval));
		}	
	}
	
	/**
	 * Function gets the latest orders from the orders table.
	 * 
	 * 
	 * @return string
	 */	
	
	
	function latestOrders($dashname)
	{
	    $sql="select a.orders_id,b.user_display_name,c.orders_status_name,a.date_purchased,a.order_total 
		from orders_table a 
		inner join users_table b on a.customers_id=b.user_id 
		inner join orders_status_table c on a.orders_status=c.orders_status_id 
		order by a.date_purchased desc 
		limit 0,8";
		$obj = new Bin_Query();
		$obj->executeQuery($sql);		
			return  Display_DAdminHome::latestOrders($obj->records,$dashname);		
	}
	
	/**
	 * Function gets all the news details from the database 
	 * 
	 * 
	 * @return string
	 */	 	

	
	function showHomeNews($dashname)
	{
		$sql = "SELECT * FROM news_table order by news_date desc LIMIT 0,8 ";
			$query1 = new Bin_Query();
			
			$query1->executeQuery($sql);
				return Display_DAdminHome::showHomeNews($query1->records,$dashname);			
	
	}
	
	/**
	 * Function generates the data need for showing the best selling products
	 * 
	 * 
	 * @return string
	 */

	function showHomeBestSellingProducts($dashname)
	{			
			$sql1 = "SELECT orders.product_id, sum( orders.product_qty ) AS cnt , prod.title , prod.category_id , prod.thumb_image, cat.category_name, prod.msrp 
					 FROM order_products_table orders , products_table prod , category_table cat 
					 WHERE orders.product_id=prod.product_id and prod.category_id=cat.category_id and prod.intro_date <= now() 
							AND status=1 GROUP BY orders.product_id 
					 ORDER BY cnt DESC 
					 LIMIT 0,8";
			$query1 = new Bin_Query();
			
			$query1->executeQuery($sql1);
				return Display_DAdminHome::showHomeBestSellingProducts($query1->records,$dashname);
	}
	
	/**
	 * Function generates all featured product from all main category
	 * 
	 * 
	 * @return string
	 */
	
	function showHomeFeaturedItems($dashname)
	{		
		$sql=" SELECT a. * , sum( c.rating ) / count( c.user_id ) AS rating, e.category_name
FROM `products_table` a
LEFT JOIN product_reviews_table c ON a.product_id = c.product_id
INNER JOIN category_table e ON a.category_id = e.category_id
WHERE a.category_id
IN (

SELECT b.category_id AS id
FROM category_table a
INNER JOIN category_table b ON a.category_id = b.category_parent_id
ORDER BY rand( )
)
AND is_featured =1
AND a.status =1
AND a.intro_date <= '".date('Y-m-d')."'
GROUP BY a.product_id
ORDER BY a.intro_date DESC
LIMIT 0 , 8 ";
		//$sql = "SELECT a.*,sum(c.rating)/count(c.user_id) as rating FROM `products_table` a left join product_reviews_table c on a.product_id=c.product_id WHERE category_id IN (SELECT b.category_id AS id FROM category_table a INNER JOIN category_table b ON a.category_id = b.category_parent_id ORDER BY rand()) and is_featured=1 and a.status=1 and a.intro_date <= '".date('Y-m-d')."' group by a.product_id  ORDER BY rand( ) limit 0,8";
	
	$query = new Bin_Query();
		$query->executeQuery($sql);
		//{
//			$flag='0';
//			$j=0;
//			$cnt=count($query->records);
//			if($cnt>0)
//			{
//				for ($i=0;$i<$cnt;$i++)
//				{		
//					foreach($query->records as $row)
//					{
//						$r[$j]=$row;
//						$prid=$row['product_id'];
//						$sqlrp='select min(msrp) as msrp from msrp_by_quantity_table where product_id ='.$productid;
//						$objrp=new Bin_Query();
//						$objrp->executeQuery($sqlrp);
//						$val=$objrp->records;
//						$minval= $val[0]['msrp'];
//						//$minval=$this->disRates($prid);
//						if($minval > 0  or $minval!='')
//							$r[$j]['msrp']= '$'.number_format($row['msrp'],2).' - $'.number_format($minval,2);
//						else
//							$r[$j]['msrp']= '$'.number_format($row['msrp'],2);
//						$j++;
//					}
//				}
				return Display_DAdminHome::showHomeFeaturedItems($query->records,$dashname);
			//}
		//}
		
		
	}
	
	/**
	 * Function generates all new product from all main category
	 * 
	 * 
	 * @return string
	 */
	
	function showHomeNewProducts($dashname)
	{		
		$sql=" SELECT a.product_id, a.title, a.thumb_image, a.msrp, a.intro_date, b.soh, sum( c.rating ) / count( c.user_id ) AS rating, e.category_name, a.brand
FROM products_table a
INNER JOIN product_inventory_table b ON a.product_id = b.product_id
LEFT JOIN product_reviews_table c ON a.product_id = c.product_id
INNER JOIN category_table e ON a.category_id = e.category_id
WHERE a.intro_date <= '".date('Y-m-d')."'
AND a.status =1
GROUP BY a.product_id
ORDER BY a.intro_date DESC
LIMIT 0 , 8
";		
		//$sql= " SELECT a.product_id, a.title, a.thumb_image, a.msrp, a.intro_date,b.soh,sum(c.rating)/count(c.user_id) as 			rating	FROM products_table a INNER JOIN	product_inventory_table b ON a.product_id=b.product_id  left join product_reviews_table c on a.product_id=c.product_id WHERE a.intro_date <= '".date('Y-m-d')."' and a.status=1 group by a.product_id ORDER BY rand( ) LIMIT 0 , 4  ";
	
	$query = new Bin_Query();
		$query->executeQuery($sql);
		//{
//			$flag='0';
//			$j=0;
//			$cnt=count($query->records);
//			if($cnt>0)
//			{
//				for ($i=0;$i<$cnt;$i++)
//				{		
//					foreach($query->records as $row)
//					{
//						$r[$j]=$row;
//						$prid=$row['product_id'];
//						$sqlrp='select min(msrp) as msrp from msrp_by_quantity_table where product_id ='.$productid;
//						$objrp=new Bin_Query();
//						$objrp->executeQuery($sqlrp);
//						$val=$objrp->records;
//						$minval= $val[0]['msrp'];
//						//$minval=$this->disRates($prid);
//						if($minval > 0  or $minval!='')
//							$r[$j]['msrp']= '$'.number_format($row['msrp'],2).' - $'.number_format($minval,2);
//						else
//							$r[$j]['msrp']= '$'.number_format($row['msrp'],2);
//						$j++;
//					}
//				}
				return Display_DAdminHome::showHomeNewProducts($query->records,$dashname);
			//}
		//}
		
		
	}
	
	/**
	 * Function gets the most search keyword frequency from the database
	 * 
	 * 
	 * @return string
	 */
	

	function showHomeMostSearchedKeywords($dashname)
	{	
			$sql = "select search_tag as keyword,search_count as cnt from search_tags_table order by search_count desc LIMIT 0,8";
			$query = new Bin_Query();
			
			$query->executeQuery($sql);
			
				return Display_DAdminHome::showHomeMostSearchedKeywords($query->records,$dashname);
			
		
		
	}
	
	/**
	 * Function gets the zeuscart news from the http://www.ajsquare.com
	 * 
	 * 
	 * @return string
	 */	

	function showHomeZeuscartNews($dashname)
	{	
		
		$varURL="http://www.ajsquare.com/zeusconvert.php";
		//$varURL="http://localhost/zeusconvert.php";
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_RETURNTRANSFER,1);
		curl_setopt($ch, CURLOPT_URL,$varURL);
		curl_setopt($ch, CURLOPT_POST,1);
		$content = curl_exec ($ch);
		
			return Display_DAdminHome::showHomeZeuscartNews($content,$dashname);
		
		
	}
	
	/**
	 * Function gets the new customer details from the orders_table.
	 * 
	 * 
	 * @return string
	 */			
	function newCustomers()
	{
	   $sql="select b.user_display_name,b.user_email,b.user_doj from orders_table a inner join users_table b on a.customers_id=b.user_id  order by b.user_doj desc limit 0,10";
	   $obj=new Bin_Query();
	   $obj->executeQuery($sql);
	   return  Display_DAdminHome::newCustomers($obj->records);
	}
   /**
	 * Function gets the new Dashboard Settings details from the  dashboard_settings table.
	 * 
	 * 
	 * @return  array
	 */			
   
    function dashSettings()
	{
	
	 $sql="SELECT  a.dash_id, b.dash_name  from dashboard_settings_table a,dashboard_items_table b where a.dash_id=b.dash_id and admin_id=".$_SESSION['adminId'];
	 $obj=new Bin_Query();
	 $obj->executeQuery($sql);
	
	   
	   return $obj->records;;
	
	}
	
	function pendstatis()
	{		
		$sql = "SELECT `category_name`
FROM `category_table`
WHERE `category_parent_id` = '0' order by category_name ";

		$query = new Bin_Query();			
		if($query->executeQuery($sql))
		{
			$cat=$query->records;
			$count=count($query->records);
			$sqlpend = "SELECT d.category_name AS main, count( a.orders_id ) AS tot 
FROM orders_table a
INNER JOIN order_products_table e ON e.order_id = a.orders_id
INNER JOIN products_table b ON e.product_id = b.product_id
INNER JOIN category_table c ON b.category_id = c.category_id
INNER JOIN category_table d ON d.category_id = c.category_parent_id
WHERE a.`orders_status` = '1'
GROUP BY main ";
			$querypend = new Bin_Query();	
			if($querypend->executeQuery($sqlpend))
			{
				$pendary=$querypend->records;
			}
			else
			{
				$pendary=array();
			}
			
			$sqlprocess = "SELECT d.category_name AS main, count( a.orders_id ) AS tot 
FROM orders_table a
INNER JOIN order_products_table e ON e.order_id = a.orders_id
INNER JOIN products_table b ON e.product_id = b.product_id
INNER JOIN category_table c ON b.category_id = c.category_id
INNER JOIN category_table d ON d.category_id = c.category_parent_id
WHERE a.`orders_status` = '2'
GROUP BY main";
			$queryprocess = new Bin_Query();	
			if($queryprocess->executeQuery($sqlprocess))
			{
				$processary=$queryprocess->records;
			}
			else
			{
				$processary=array();
			}
			
			$sqldeliver = "SELECT d.category_name AS main, count( a.orders_id ) AS tot 
FROM orders_table a
INNER JOIN order_products_table e ON e.order_id = a.orders_id
INNER JOIN products_table b ON e.product_id = b.product_id
INNER JOIN category_table c ON b.category_id = c.category_id
INNER JOIN category_table d ON d.category_id = c.category_parent_id
WHERE a.`orders_status` = '3'
GROUP BY main";
			$querydeliver = new Bin_Query();	
			if($querydeliver->executeQuery($sqldeliver))
			{
				$deliverary=$querydeliver->records;
			}
			else
			{
				$deliverary=array();
			}
			
			$sqlwait = "SELECT d.category_name AS main, count( a.orders_id ) AS tot 
FROM orders_table a
INNER JOIN order_products_table e ON e.order_id = a.orders_id
INNER JOIN products_table b ON e.product_id = b.product_id
INNER JOIN category_table c ON b.category_id = c.category_id
INNER JOIN category_table d ON d.category_id = c.category_parent_id
WHERE a.`orders_status` = '4'
GROUP BY main";
			$querywait = new Bin_Query();	
			if($querywait->executeQuery($sqlwait))
			{
				$waitary=$querywait->records;
			}
			else
			{
				$waitary=array();
			}
			
			$pagef=($_GET['len']-1)*8;
			$paget=$_GET['len']*8;
			$output ='<?xml version="1.0" encoding="utf-8"?><root><cat name="" cat_id="" pending="" processing="" await="" completed="" />';
			for($i=$pagef;$i<$paget;$i++)
			{
				$pendres=0;$processres=0;$deliverres=0;$waitres=0;
				if(!empty($pendary))
				{
					for($a=0;$a<count($pendary);$a++)
					{
						if($cat[$i]['category_name']==$pendary[$a]['main'])
							$pendres=$pendary[$a]['tot'];
					}
				}
				else
					$pendres=0;
					
				if(!empty($processary))
				{
					for($y=0;$y<count($processary);$y++)
					{
						if($cat[$i]['category_name']==$processary[$y]['main'])
							$processres=$processary[$y]['tot'];
					}
				}
				else
					$processres=0;
					
				if(!empty($deliverary))
				{
					for($t=0;$t<count($deliverary);$t++)
					{
						if($cat[$i]['category_name']==$deliverary[$t]['main'])
							$deliverres=$deliverary[$t]['tot'];
					}
				}
				else
					$deliverres=0;
					
				if(!empty($waitary))
				{
					for($t=0;$t<count($waitary);$t++)
					{
						if($cat[$i]['category_name']==$waitary[$t]['main'])
							$waitres=$waitary[$t]['tot'];
					}
				}
				else
					$waitres=0;
					
				$serialno=$i+1;				
		
				$output .='<cat name="'.$cat[$i]['category_name'].'" cat_id="'.$serialno.'" pending="'.$pendres.'" processing="'.$processres.'" await="'.$waitres.'" completed="'.$deliverres.'"/>';
				
			}
			$last=ceil($count/8);
			if($_GET['len']==1)
			{
				$output .='<next>yes</next>';						
				$output .='<back>no</back>';						
			}
			if($_GET['len']!=1 && $_GET['len']!=$last)
			{
				$output .='<next>yes</next>';						
				$output .='<back>yes</back>';						
			}
			if($_GET['len']==$last)
			{
				$output .='<next>no</next>';						
				$output .='<back>yes</back>';						
			}
			$output .='</root>';
				
		}
		return $output;
	}
	
	function beststatis()
	{		
		$sql = "SELECT `category_name`
FROM `category_table`
WHERE `category_parent_id` = '0' order by category_name ";

		$query = new Bin_Query();			
		if($query->executeQuery($sql))
		{
			$cat=$query->records;
			$count=count($query->records);
			$sqlrevenue = "SELECT d.category_name AS main, sum( ord.order_total ) AS tot
FROM orders_table ord, order_products_table prd, products_table prod, category_table c, category_table d
WHERE ord.orders_id = prd.order_id
AND prd.product_id = prod.product_id
AND prd.product_qty <> '0'
AND orders_status = '3'
AND d.category_id = c.category_parent_id
AND prod.category_id = c.category_id
GROUP BY main";
			$queryrevenue = new Bin_Query();	
			if($queryrevenue->executeQuery($sqlrevenue))
			{
				$revenueary=$queryrevenue->records;
			}
			else
			{
				$revenueary=array();
			}
			
			$sqlunit = "SELECT d.category_name AS main, sum( prd.product_qty ) AS tot
FROM orders_table ord, order_products_table prd, products_table prod, category_table c, category_table d
WHERE ord.orders_id = prd.order_id
AND prd.product_id = prod.product_id
AND orders_status = '3'
AND d.category_id = c.category_parent_id
AND prod.category_id = c.category_id
GROUP BY main";
			$queryunit = new Bin_Query();	
			if($queryunit->executeQuery($sqlunit))
			{
				$unitary=$queryunit->records;
			}
			else
			{
				$unitary=array();
			}
			
			$sqlbest = "SELECT d.category_name AS main, sum( orders.product_qty ) AS tot
FROM order_products_table orders, products_table prod, category_table c, category_table d
WHERE orders.product_id = prod.product_id
AND prod.intro_date <= now( )
AND STATUS =1
AND d.category_id = c.category_parent_id
AND prod.category_id = c.category_id
GROUP BY  main";
			$querybest = new Bin_Query();	
			if($querybest->executeQuery($sqlbest))
			{
				$bestary=$querybest->records;
			}
			else
			{
				$bestary=array();
			}
			
			$pagef=($_GET['len']-1)*8;
			$paget=$_GET['len']*8;
			$output ='<?xml version="1.0" encoding="utf-8"?><root><cat name="" cat_id="" unit="" revenue="" best="" />';
			for($i=$pagef;$i<$paget;$i++)
			{
				$bestres=0;$unitres=0;$revenueres=0;
				if(!empty($bestary))
				{
					for($a=0;$a<count($bestary);$a++)
					{
						if($cat[$i]['category_name']==$bestary[$a]['main'])
							$bestres=$bestary[$a]['tot'];
					}
				}
				else
					$bestres=0;
					
				if(!empty($unitary))
				{
					for($y=0;$y<count($unitary);$y++)
					{
						if($cat[$i]['category_name']==$unitary[$y]['main'])
							$unitres=$unitary[$y]['tot'];
					}
				}
				else
					$unitres=0;
					
				if(!empty($revenueary))
				{
					for($t=0;$t<count($revenueary);$t++)
					{
						if($cat[$i]['category_name']==$revenueary[$t]['main'])
							$revenueres=$revenueary[$t]['tot'];
					}
				}
				else
					$revenueres=0;				
					
				$serialno=$i+1;				
		
				$output .='<cat name="'.$cat[$i]['category_name'].'" cat_id="'.$serialno.'" unit="'.$unitres.'" revenue="'.$revenueres.'" best="'.$bestres.'" />';
				
			}
			$last=ceil($count/8);
			if($_GET['len']==1)
			{
				$output .='<next>yes</next>';						
				$output .='<back>no</back>';						
			}
			if($_GET['len']!=1 && $_GET['len']!=$last)
			{
				$output .='<next>yes</next>';						
				$output .='<back>yes</back>';						
			}
			if($_GET['len']==$last)
			{
				$output .='<next>no</next>';						
				$output .='<back>yes</back>';						
			}
			$output .='</root>';
				
		}
		return $output;
	}
	
	function locationstatis()
	{		
		$sql = "SELECT cou_name FROM country_table";

		$query = new Bin_Query();			
		if($query->executeQuery($sql))
		{
			$cat=$query->records;
			$count=count($query->records);
			$sqlcustomer = "SELECT cou_name as main, count( user_id ) AS tot
FROM users_table a
INNER JOIN country_table b ON a.user_country = b.cou_code
GROUP BY a.user_country";
			$querycustomer = new Bin_Query();	
			if($querycustomer->executeQuery($sqlcustomer))
			{
				$customerary=$querycustomer->records;
			}
			else
			{
				$customerary=array();
			}
			
			$sqlunit = "SELECT d.cou_name AS main, sum( prd.product_qty ) AS tot
FROM orders_table ord, order_products_table prd, products_table prod, users_table c, country_table d
WHERE ord.orders_id = prd.order_id
AND prd.product_id = prod.product_id
AND orders_status = '3'
AND d.cou_code = c.user_country
AND ord.customers_id = c.user_id
GROUP BY main";
			$queryunit = new Bin_Query();	
			if($queryunit->executeQuery($sqlunit))
			{
				$unitary=$queryunit->records;
			}
			else
			{
				$unitary=array();
			}
			
			$sqlrevenue = "SELECT d.cou_name AS main, sum( ord.order_total ) AS tot
FROM orders_table ord, order_products_table prd, products_table prod, users_table c, country_table d
WHERE ord.orders_id = prd.order_id
AND prd.product_id = prod.product_id
AND prd.product_qty <> '0'
AND orders_status = '3'
AND d.cou_code = c.user_country
AND ord.customers_id = c.user_id
GROUP BY main";
			$queryrevenue = new Bin_Query();	
			if($queryrevenue->executeQuery($sqlrevenue))
			{
				$revenueary=$queryrevenue->records;
			}
			else
			{
				$revenueary=array();
			}
			
			$pagef=($_GET['len']-1)*8;
			$paget=$_GET['len']*8;
			$output ='<?xml version="1.0" encoding="utf-8"?><root><cat name="" cat_id="" customer=""  unit="" revenue="" />';
			for($i=$pagef;$i<$paget;$i++)
			{
				$custres=0;$unitres=0;$revenueres=0;
				if(!empty($customerary))
				{
					for($a=0;$a<count($customerary);$a++)
					{
						if($cat[$i]['category_name']==$customerary[$a]['main'])
							$custres=$customerary[$a]['tot'];
					}
				}
				else
					$custres=0;
					
				if(!empty($unitary))
				{
					for($y=0;$y<count($unitary);$y++)
					{
						if($cat[$i]['category_name']==$unitary[$y]['main'])
							$unitres=$unitary[$y]['tot'];
					}
				}
				else
					$unitres=0;
					
				if(!empty($revenueary))
				{
					for($t=0;$t<count($revenueary);$t++)
					{
						if($cat[$i]['category_name']==$revenueary[$t]['main'])
							$revenueres=$revenueary[$t]['tot'];
					}
				}
				else
					$revenueres=0;				
					
				$serialno=$i+1;				
		
				$output .='<cat name="'.$cat[$i]['category_name'].'" cat_id="'.$serialno.'" customer="'.$custres.'"  unit="'.$unitres.'" revenue="'.$revenueres.'" />';
				
			}
			$last=ceil($count/8);
			if($_GET['len']==1)
			{
				$output .='<next>yes</next>';						
				$output .='<back>no</back>';						
			}
			if($_GET['len']!=1 && $_GET['len']!=$last)
			{
				$output .='<next>yes</next>';						
				$output .='<back>yes</back>';						
			}
			if($_GET['len']==$last)
			{
				$output .='<next>no</next>';						
				$output .='<back>yes</back>';						
			}
			$output .='</root>';
				
		}
		return $output;
	}
	
	function pendbi()
	{		
		$sql = "SELECT `cou_name` FROM `country_table` ";

		$query = new Bin_Query();			
		if($query->executeQuery($sql))
		{
			$cat=$query->records;
			$count=count($query->records);
			$sqlpend = "SELECT b.cou_name AS main, count( a.orders_id )
FROM orders_table a
INNER JOIN users_table e ON e.user_id = a.customers_id
INNER JOIN country_table b ON e.user_country = b.cou_code
WHERE a.`orders_status` = '1'
GROUP BY main";
			$querypend = new Bin_Query();	
			if($querypend->executeQuery($sqlpend))
			{
				$pendary=$querypend->records;
			}
			else
			{
				$pendary=array();
			}
			
			$sqlprocess = "SELECT b.cou_name AS main, count( a.orders_id )
FROM orders_table a
INNER JOIN users_table e ON e.user_id = a.customers_id
INNER JOIN country_table b ON e.user_country = b.cou_code
WHERE a.`orders_status` = '2'
GROUP BY main";
			$queryprocess = new Bin_Query();	
			if($queryprocess->executeQuery($sqlprocess))
			{
				$processary=$queryprocess->records;
			}
			else
			{
				$processary=array();
			}
			
			$sqlwait = "SELECT b.cou_name AS main, count( a.orders_id )
FROM orders_table a
INNER JOIN users_table e ON e.user_id = a.customers_id
INNER JOIN country_table b ON e.user_country = b.cou_code
WHERE a.`orders_status` = '4'
GROUP BY main";
			$querywait = new Bin_Query();	
			if($querywait->executeQuery($sqlwait))
			{
				$waitary=$querywait->records;
			}
			else
			{
				$waitary=array();
			}
			
			$pagef=($_GET['len']-1)*8;
			$paget=$_GET['len']*8;
			$output ='<?xml version="1.0" encoding="utf-8"?><root><cat name="" cat_id="" pending="" processing="" await="" />';
			for($i=$pagef;$i<$paget;$i++)
			{
				$pendres=0;$processres=0;$waitres=0;
				if(!empty($pendary))
				{
					for($a=0;$a<count($pendary);$a++)
					{
						if($cat[$i]['cou_name']==$pendary[$a]['main'])
							$pendres=$pendary[$a]['tot'];
					}
				}
				else
					$pendres=0;
					
				if(!empty($processary))
				{
					for($y=0;$y<count($processary);$y++)
					{
						if($cat[$i]['cou_name']==$processary[$y]['main'])
							$processres=$processary[$y]['tot'];
					}
				}
				else
					$processres=0;			
					
				if(!empty($waitary))
				{
					for($t=0;$t<count($waitary);$t++)
					{
						if($cat[$i]['cou_name']==$waitary[$t]['main'])
							$waitres=$waitary[$t]['tot'];
					}
				}
				else
					$waitres=0;
					
				$serialno=$i+1;				
		
				$output .='<cat name="'.$cat[$i]['category_name'].'" cat_id="'.$serialno.'" pending="'.$pendres.'" processing="'.$processres.'" await="'.$waitres.'" />';
				
			}
			$last=ceil($count/8);
			if($_GET['len']==1)
			{
				$output .='<next>yes</next>';						
				$output .='<back>no</back>';						
			}
			if($_GET['len']!=1 && $_GET['len']!=$last)
			{
				$output .='<next>yes</next>';						
				$output .='<back>yes</back>';						
			}
			if($_GET['len']==$last)
			{
				$output .='<next>no</next>';						
				$output .='<back>yes</back>';						
			}
			$output .='</root>';
				
		}
		return $output;
	}
	
	function catvsinv()
	{		
		$sql = "SELECT `category_name`
FROM `category_table`
WHERE `category_parent_id` = '0' order by category_name ";

		$query = new Bin_Query();			
		if($query->executeQuery($sql))
		{
			$cat=$query->records;
			$count=count($query->records);
			$sqllow = "SELECT  d.category_name AS main,count( a.soh ) as tot 
FROM product_inventory_table a
INNER JOIN products_table b ON a.product_id = b.product_id
INNER JOIN category_table c ON b.category_id = c.category_id
INNER JOIN category_table d ON d.category_id = c.category_parent_id
WHERE a.rol >= a.soh
GROUP BY main
ORDER BY main";
			$querylow = new Bin_Query();	
			if($querylow->executeQuery($sqllow))
			{
				$lowary=$querylow->records;
			}
			else
			{
				$lowary=array();
			}
			
			$sqlno = "SELECT  d.category_name AS main,count( a.soh ) as tot 
FROM product_inventory_table a
INNER JOIN products_table b ON a.product_id = b.product_id
INNER JOIN category_table c ON b.category_id = c.category_id
INNER JOIN category_table d ON d.category_id = c.category_parent_id
WHERE a.soh<=0
GROUP BY main
ORDER BY main";
			$queryno = new Bin_Query();	
			if($queryno->executeQuery($sqlno))
			{
				$noary=$queryno->records;
			}
			else
			{
				$noary=array();
			}
			
			$sqlin = "SELECT d.category_name AS main,count( a.soh )  as tot
FROM product_inventory_table a
INNER JOIN products_table b ON a.product_id = b.product_id
INNER JOIN category_table c ON b.category_id = c.category_id
INNER JOIN category_table d ON d.category_id = c.category_parent_id
WHERE a.rol < a.soh
GROUP BY main
ORDER BY main";
			$queryin = new Bin_Query();	
			if($queryin->executeQuery($sqlin))
			{
				$inary=$queryin->records;
			}
			else
			{
				$inary=array();
			}
			
			$pagef=($_GET['len']-1)*8;
			$paget=$_GET['len']*8;
			$output ='<?xml version="1.0" encoding="utf-8"?><root><cat name="" cat_id="" low="" instock="" nostock="" />';
			for($i=$pagef;$i<$paget;$i++)
			{
				$inres=0;$nores=0;$lowres=0;
				if(!empty($inary))
				{
					for($a=0;$a<count($inary);$a++)
					{
						if($cat[$i]['category_name']==$inary[$a]['main'])
							$inres=$inary[$a]['tot'];
					}
				}
				else
					$inres=0;
					
				if(!empty($noary))
				{
					for($y=0;$y<count($noary);$y++)
					{
						if($cat[$i]['category_name']==$noary[$y]['main'])
							$nores=$noary[$y]['tot'];
					}
				}
				else
					$nores=0;
					
				if(!empty($lowary))
				{
					for($t=0;$t<count($lowary);$t++)
					{
						if($cat[$i]['category_name']==$lowary[$t]['main'])
							$lowres=$lowary[$t]['tot'];
					}
				}
				else
					$lowres=0;
					
				$serialno=$i+1;				
		
				$output .='<cat name="'.$cat[$i]['category_name'].'" cat_id="'.$serialno.'" low="'.$lowres.'" instock="'.$inres.'" nostock="'.$nores.'" />';
				
			}
			$last=ceil($count/8);
			if($_GET['len']==1)
			{
				$output .='<next>yes</next>';						
				$output .='<back>no</back>';						
			}
			if($_GET['len']!=1 && $_GET['len']!=$last)
			{
				$output .='<next>yes</next>';						
				$output .='<back>yes</back>';						
			}
			if($_GET['len']==$last)
			{
				$output .='<next>no</next>';						
				$output .='<back>yes</back>';						
			}
			$output .='</root>';
				
		}
		return $output;
	}
	
	function catvsprod()
	{		
		$sql = "SELECT `category_name`
FROM `category_table`
WHERE `category_parent_id` = '0' order by category_name ";

		$query = new Bin_Query();			
		if($query->executeQuery($sql))
		{
			$cat=$query->records;
			$count=count($query->records);
			$sqltoday = "SELECT d.category_name AS main, sum( a.product_qty ) AS tot
FROM order_products_table a
INNER JOIN products_table b ON a.product_id = b.product_id
INNER JOIN category_table c ON b.category_id = c.category_id
INNER JOIN category_table d ON d.category_id = c.category_parent_id
INNER JOIN orders_table e ON e.orders_id = a.order_id
WHERE `order_id`
IN (

SELECT orders_id
FROM `orders_table`
WHERE `orders_status` = '3'
)
AND TO_DAYS( NOW( ) ) - TO_DAYS( e.date_purchased ) = '0'
GROUP BY main 
order by main ";
			$querytoday = new Bin_Query();	
			if($querytoday->executeQuery($sqltoday))
			{
				$todayary=$querytoday->records;
			}
			else
			{
				$todayary=array();
			}
			
			$sqlyester = "SELECT d.category_name AS main, sum( a.product_qty ) AS tot
FROM order_products_table a
INNER JOIN products_table b ON a.product_id = b.product_id
INNER JOIN category_table c ON b.category_id = c.category_id
INNER JOIN category_table d ON d.category_id = c.category_parent_id
INNER JOIN orders_table e ON e.orders_id = a.order_id
WHERE `order_id`
IN (

SELECT orders_id
FROM `orders_table`
WHERE `orders_status` = '3'
)
AND TO_DAYS( NOW( ) ) - TO_DAYS( e.date_purchased ) = '1'
GROUP BY main 
order by main ";
			$queryyester = new Bin_Query();	
			if($queryyester->executeQuery($sqlyester))
			{
				$yesterary=$queryyester->records;
			}
			else
			{
				$yesterary=array();
			}
			
			$sqlall = "SELECT d.category_name AS main, sum( a.product_qty ) AS tot
FROM order_products_table a
INNER JOIN products_table b ON a.product_id = b.product_id
INNER JOIN category_table c ON b.category_id = c.category_id
INNER JOIN category_table d ON d.category_id = c.category_parent_id
INNER JOIN orders_table e ON e.orders_id = a.order_id
WHERE `order_id`
IN (

SELECT orders_id
FROM `orders_table`
WHERE `orders_status` = '3'
)
AND TO_DAYS( NOW( ) ) - TO_DAYS( e.date_purchased ) > '1'
GROUP BY main 
order by main ";
			$queryall = new Bin_Query();	
			if($queryall->executeQuery($sqlall))
			{
				$allary=$queryall->records;
			}
			else
			{
				$allary=array();
			}
			
			$pagef=($_GET['len']-1)*8;
		$paget=$_GET['len']*8;
			$output ='<?xml version="1.0" encoding="utf-8"?><root><cat name="" cat_id="" old="" ystrday="" today="" />';
			for($i=$pagef;$i<$paget;$i++)
			{
				$allres=0;$yesres=0;$tores=0;
				if(!empty($allary))
				{
					for($a=0;$a<count($allary);$a++)
					{
						if($cat[$i]['category_name']==$allary[$a]['main'])
							$allres=$allary[$a]['tot'];
					}
				}
				else
					$allres=0;
					
				if(!empty($yesterary))
				{
					for($y=0;$y<count($yesterary);$y++)
					{
						if($cat[$i]['category_name']==$yesterary[$y]['main'])
							$yesres=$yesterary[$y]['tot'];
					}
				}
				else
					$yesres=0;
					
				if(!empty($todayary))
				{
					for($t=0;$t<count($todayary);$t++)
					{
						if($cat[$i]['category_name']==$todayary[$t]['main'])
							$tores=$todayary[$t]['tot'];
					}
				}
				else
					$tores=0;
					
				$serialno=$i+1;				
		
				$output .='<cat name="'.$cat[$i]['category_name'].'" cat_id="'.$serialno.'" old="'.$allres.'" ystrday="'.$yesres.'" today="'.$tores.'" />';
				
			}
			$last=ceil($count/8);
			if($_GET['len']==1)
			{
				$output .='<next>yes</next>';						
				$output .='<back>no</back>';						
			}
			if($_GET['len']!=1 && $_GET['len']!=$last)
			{
				$output .='<next>yes</next>';						
				$output .='<back>yes</back>';						
			}
			if($_GET['len']==$last)
			{
				$output .='<next>no</next>';						
				$output .='<back>yes</back>';						
			}
			$output .='</root>';
				
		}
		return $output;
	}

}
?>	